@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtCharts/QBarModelMapper>
 #include <private/qbarmodelmapper_p.h>
@@ -405,7 +379,7 @@ void QBarModelMapperPrivate::barSetsAdded(const QList<QBarSet *> &sets)
     if (m_seriesSignalsBlock)
         return;
 
-    if (sets.count() == 0)
+    if (sets.size() == 0)
         return;
 
     int firstIndex = m_series->barSets().indexOf(sets.at(0));
@@ -413,7 +387,7 @@ void QBarModelMapperPrivate::barSetsAdded(const QList<QBarSet *> &sets)
         return;
 
     int maxCount = 0;
-    for (int i = 0; i < sets.count(); i++) {
+    for (int i = 0; i < sets.size(); i++) {
         if (sets.at(i)->count() > m_count)
             maxCount = sets.at(i)->count();
     }
@@ -421,7 +395,7 @@ void QBarModelMapperPrivate::barSetsAdded(const QList<QBarSet *> &sets)
     if (m_count != -1 && m_count < maxCount)
         m_count = maxCount;
 
-    m_lastBarSetSection += sets.count();
+    m_lastBarSetSection += sets.size();
 
     blockModelSignals();
     int modelCapacity = m_orientation == Qt::Vertical ? m_model->rowCount() - m_first : m_model->columnCount() - m_first;
@@ -433,12 +407,12 @@ void QBarModelMapperPrivate::barSetsAdded(const QList<QBarSet *> &sets)
     }
 
     if (m_orientation == Qt::Vertical)
-        m_model->insertColumns(firstIndex + m_firstBarSetSection, sets.count());
+        m_model->insertColumns(firstIndex + m_firstBarSetSection, sets.size());
     else
-        m_model->insertRows(firstIndex + m_firstBarSetSection, sets.count());
+        m_model->insertRows(firstIndex + m_firstBarSetSection, sets.size());
 
 
-    for (int i = firstIndex + m_firstBarSetSection; i < firstIndex + m_firstBarSetSection + sets.count(); i++) {
+    for (int i = firstIndex + m_firstBarSetSection; i < firstIndex + m_firstBarSetSection + sets.size(); i++) {
         m_model->setHeaderData(i, m_orientation == Qt::Vertical ? Qt::Horizontal : Qt::Vertical, sets.at(i - firstIndex - m_firstBarSetSection)->label());
         for (int j = 0; j < sets.at(i - firstIndex - m_firstBarSetSection)->count(); j++)
             m_model->setData(barModelIndex(i, j), sets.at(i - firstIndex - m_firstBarSetSection)->at(j));
@@ -452,23 +426,23 @@ void QBarModelMapperPrivate::barSetsRemoved(const QList<QBarSet *> &sets)
     if (m_seriesSignalsBlock)
         return;
 
-    if (sets.count() == 0)
+    if (sets.size() == 0)
         return;
 
     int firstIndex = m_barSets.indexOf(sets.at(0));
     if (firstIndex == -1)
         return;
 
-    m_lastBarSetSection -= sets.count();
+    m_lastBarSetSection -= sets.size();
 
-    for (int i = firstIndex + sets.count() - 1; i >= firstIndex; i--)
+    for (int i = firstIndex + sets.size() - 1; i >= firstIndex; i--)
         m_barSets.removeAt(i);
 
     blockModelSignals();
     if (m_orientation == Qt::Vertical)
-        m_model->removeColumns(firstIndex + m_firstBarSetSection, sets.count());
+        m_model->removeColumns(firstIndex + m_firstBarSetSection, sets.size());
     else
-        m_model->removeRows(firstIndex + m_firstBarSetSection, sets.count());
+        m_model->removeRows(firstIndex + m_firstBarSetSection, sets.size());
     blockModelSignals(false);
     initializeBarFromModel();
 }
