@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtCharts/QChart>
 #include <private/qchart_p.h>
@@ -477,7 +451,7 @@ bool QChart::isZoomed()
 QAbstractAxis *QChart::axisX(QAbstractSeries *series) const
 {
     QList<QAbstractAxis *> axisList = axes(Qt::Horizontal, series);
-    if (axisList.count())
+    if (axisList.size())
         return axisList[0];
     return 0;
 }
@@ -494,7 +468,7 @@ QAbstractAxis *QChart::axisX(QAbstractSeries *series) const
 QAbstractAxis *QChart::axisY(QAbstractSeries *series) const
 {
     QList<QAbstractAxis *> axisList = axes(Qt::Vertical, series);
-    if (axisList.count())
+    if (axisList.size())
         return axisList[0];
     return 0;
 }
