@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "declarativebarseries_p.h"
 #include <QtCharts/QBarSet>
@@ -76,10 +50,10 @@ void DeclarativeBarSet::setValues(QVariantList values)
     while (count())
         remove(count() - 1);
 
-    if (values.count() > 0 && values.at(0).canConvert<QPoint>()) {
+    if (values.size() > 0 && values.at(0).canConvert<QPoint>()) {
         // Create list of values for appending if the first item is Qt.point
         int maxValue = 0;
-        for (int i = 0; i < values.count(); i++) {
+        for (int i = 0; i < values.size(); i++) {
             if (values.at(i).canConvert<QPoint>() &&
                     values.at(i).toPoint().x() > maxValue) {
                 maxValue = values.at(i).toPoint().x();
@@ -89,17 +63,17 @@ void DeclarativeBarSet::setValues(QVariantList values)
         QList<qreal> indexValueList;
         indexValueList.resize(maxValue + 1);
 
-        for (int i = 0; i < values.count(); i++) {
+        for (int i = 0; i < values.size(); i++) {
             if (values.at(i).canConvert<QPoint>()) {
                 indexValueList.replace(values.at(i).toPoint().x(), values.at(i).toPointF().y());
             }
         }
 
-        for (int i = 0; i < indexValueList.count(); i++)
+        for (int i = 0; i < indexValueList.size(); i++)
             QBarSet::append(indexValueList.at(i));
 
     } else {
-        for (int i(0); i < values.count(); i++) {
+        for (int i(0); i < values.size(); i++) {
             if (values.at(i).canConvert<double>())
                 QBarSet::append(values[i].toDouble());
         }
@@ -179,7 +153,7 @@ void DeclarativeBarSeries::appendSeriesChildren(QQmlListProperty<QObject> *list,
 DeclarativeBarSet *DeclarativeBarSeries::at(int index)
 {
     QList<QBarSet *> setList = barSets();
-    if (index >= 0 && index < setList.count())
+    if (index >= 0 && index < setList.size())
         return qobject_cast<DeclarativeBarSet *>(setList[index]);
 
     return 0;
@@ -243,7 +217,7 @@ void DeclarativeStackedBarSeries::appendSeriesChildren(QQmlListProperty<QObject>
 DeclarativeBarSet *DeclarativeStackedBarSeries::at(int index)
 {
     QList<QBarSet *> setList = barSets();
-    if (index >= 0 && index < setList.count())
+    if (index >= 0 && index < setList.size())
         return qobject_cast<DeclarativeBarSet *>(setList[index]);
 
     return 0;
@@ -306,7 +280,7 @@ void DeclarativePercentBarSeries::appendSeriesChildren(QQmlListProperty<QObject>
 DeclarativeBarSet *DeclarativePercentBarSeries::at(int index)
 {
     QList<QBarSet *> setList = barSets();
-    if (index >= 0 && index < setList.count())
+    if (index >= 0 && index < setList.size())
         return qobject_cast<DeclarativeBarSet *>(setList[index]);
 
     return 0;
@@ -369,7 +343,7 @@ void DeclarativeHorizontalBarSeries::appendSeriesChildren(QQmlListProperty<QObje
 DeclarativeBarSet *DeclarativeHorizontalBarSeries::at(int index)
 {
     QList<QBarSet *> setList = barSets();
-    if (index >= 0 && index < setList.count())
+    if (index >= 0 && index < setList.size())
         return qobject_cast<DeclarativeBarSet *>(setList[index]);
 
     return 0;
@@ -432,7 +406,7 @@ void DeclarativeHorizontalStackedBarSeries::appendSeriesChildren(QQmlListPropert
 DeclarativeBarSet *DeclarativeHorizontalStackedBarSeries::at(int index)
 {
     QList<QBarSet *> setList = barSets();
-    if (index >= 0 && index < setList.count())
+    if (index >= 0 && index < setList.size())
         return qobject_cast<DeclarativeBarSet *>(setList[index]);
 
     return 0;
@@ -495,7 +469,7 @@ void DeclarativeHorizontalPercentBarSeries::appendSeriesChildren(QQmlListPropert
 DeclarativeBarSet *DeclarativeHorizontalPercentBarSeries::at(int index)
 {
     QList<QBarSet *> setList = barSets();
-    if (index >= 0 && index < setList.count())
+    if (index >= 0 && index < setList.size())
         return qobject_cast<DeclarativeBarSet *>(setList[index]);
 
     return 0;
