@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtTest/QtTest>
 #include <QtCharts/QHorizontalPercentBarSeries>
@@ -120,13 +94,13 @@ void tst_QHorizontalPercentBarSeries::setLabelsFormat()
 
     QString format("(@value)");
     m_barseries->setLabelsFormat(format);
-    TRY_COMPARE(labelsFormatSpy.count(), 1);
+    TRY_COMPARE(labelsFormatSpy.size(), 1);
     QList<QVariant> arguments = labelsFormatSpy.takeFirst();
     QVERIFY(arguments.at(0).toString() == format);
     QCOMPARE(m_barseries->labelsFormat(), format);
 
     m_barseries->setLabelsFormat(QString());
-    TRY_COMPARE(labelsFormatSpy.count(), 1);
+    TRY_COMPARE(labelsFormatSpy.size(), 1);
     arguments = labelsFormatSpy.takeFirst();
     QVERIFY(arguments.at(0).toString() == QString());
     QCOMPARE(m_barseries->labelsFormat(), QString());
@@ -139,28 +113,28 @@ void tst_QHorizontalPercentBarSeries::setLabelsPosition()
     QCOMPARE(m_barseries->labelsPosition(), QHorizontalPercentBarSeries::LabelsCenter);
 
     m_barseries->setLabelsPosition(QHorizontalPercentBarSeries::LabelsInsideEnd);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     QList<QVariant> arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
             == QHorizontalPercentBarSeries::LabelsInsideEnd);
     QCOMPARE(m_barseries->labelsPosition(), QHorizontalPercentBarSeries::LabelsInsideEnd);
 
     m_barseries->setLabelsPosition(QHorizontalPercentBarSeries::LabelsInsideBase);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
             == QHorizontalPercentBarSeries::LabelsInsideBase);
     QCOMPARE(m_barseries->labelsPosition(), QHorizontalPercentBarSeries::LabelsInsideBase);
 
     m_barseries->setLabelsPosition(QHorizontalPercentBarSeries::LabelsOutsideEnd);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
             == QHorizontalPercentBarSeries::LabelsOutsideEnd);
     QCOMPARE(m_barseries->labelsPosition(), QHorizontalPercentBarSeries::LabelsOutsideEnd);
 
     m_barseries->setLabelsPosition(QHorizontalPercentBarSeries::LabelsCenter);
-    TRY_COMPARE(labelsPositionSpy.count(), 1);
+    TRY_COMPARE(labelsPositionSpy.size(), 1);
     arguments = labelsPositionSpy.takeFirst();
     QVERIFY(arguments.at(0).value<QAbstractBarSeries::LabelsPosition>()
             == QHorizontalPercentBarSeries::LabelsCenter);
@@ -174,7 +148,7 @@ void tst_QHorizontalPercentBarSeries::setLabelsAngle()
     QCOMPARE(m_barseries->labelsAngle(), 0.0);
 
     m_barseries->setLabelsAngle(55.0);
-    TRY_COMPARE(labelsAngleSpy.count(), 1);
+    TRY_COMPARE(labelsAngleSpy.size(), 1);
     QList<QVariant> arguments = labelsAngleSpy.takeFirst();
     QVERIFY(arguments.at(0).value<qreal>() == 55.0);
     QCOMPARE(m_barseries->labelsAngle(), 55.0);
@@ -245,7 +219,7 @@ void tst_QHorizontalPercentBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -257,7 +231,7 @@ void tst_QHorizontalPercentBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -269,7 +243,7 @@ void tst_QHorizontalPercentBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(4).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -281,7 +255,7 @@ void tst_QHorizontalPercentBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -293,7 +267,7 @@ void tst_QHorizontalPercentBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(3).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -305,7 +279,7 @@ void tst_QHorizontalPercentBarSeries::mouseclicked()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(5).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -383,14 +357,14 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
 // move mouse to left border
     QTest::mouseMove(view.viewport(), QPoint(0, layout.at(4).center().y()));
     QCoreApplication::processEvents(QEventLoop::AllEvents, 10000);
-    TRY_COMPARE(seriesIndexSpy.count(), 0);
+    TRY_COMPARE(seriesIndexSpy.size(), 0);
 
 //=======================================================================
 // move mouse on top of set1
     QTest::mouseMove(view.viewport(), layout.at(4).center().toPoint());
-    TRY_COMPARE(seriesIndexSpy.count(), 1);
-    TRY_COMPARE(setIndexSpy1.count(), 1);
-    TRY_COMPARE(setIndexSpy2.count(), 0);
+    TRY_COMPARE(seriesIndexSpy.size(), 1);
+    TRY_COMPARE(setIndexSpy1.size(), 1);
+    TRY_COMPARE(setIndexSpy2.size(), 0);
 
     QList<QVariant> seriesIndexSpyArg = seriesIndexSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesIndexSpyArg.at(2)), set1);
@@ -404,9 +378,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
 //=======================================================================
 // move mouse from top of set1 to top of set2
     QTest::mouseMove(view.viewport(), layout.at(5).center().toPoint());
-    TRY_COMPARE(seriesIndexSpy.count(), 2);
-    TRY_COMPARE(setIndexSpy1.count(), 1);
-    TRY_COMPARE(setIndexSpy2.count(), 1);
+    TRY_COMPARE(seriesIndexSpy.size(), 2);
+    TRY_COMPARE(setIndexSpy1.size(), 1);
+    TRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should leave set1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -431,9 +405,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
 //=======================================================================
 // move mouse from top of set2 to background
     QTest::mouseMove(view.viewport(), QPoint(layout.at(5).center().x(), 0));
-    TRY_COMPARE(seriesIndexSpy.count(), 1);
-    TRY_COMPARE(setIndexSpy1.count(), 0);
-    TRY_COMPARE(setIndexSpy2.count(), 1);
+    TRY_COMPARE(seriesIndexSpy.size(), 1);
+    TRY_COMPARE(setIndexSpy1.size(), 0);
+    TRY_COMPARE(setIndexSpy2.size(), 1);
 
     // should leave set2
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -449,9 +423,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
 // move mouse on top of set1, bar0 to check the index (hover into set1)
     QTest::mouseMove(view.viewport(), layout.at(0).center().toPoint());
 
-    TRY_COMPARE(seriesIndexSpy.count(), 1);
-    TRY_COMPARE(setIndexSpy1.count(), 1);
-    TRY_COMPARE(setIndexSpy2.count(), 0);
+    TRY_COMPARE(seriesIndexSpy.size(), 1);
+    TRY_COMPARE(setIndexSpy1.size(), 1);
+    TRY_COMPARE(setIndexSpy2.size(), 0);
 
     //should enter set1, bar0
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -473,9 +447,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
     QTest::mouseMove(view.viewport(), layout.at(1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 10000);
 
-    TRY_COMPARE(seriesIndexSpy.count(), 2);
-    TRY_COMPARE(setIndexSpy1.count(), 1);
-    TRY_COMPARE(setIndexSpy2.count(), 1);
+    TRY_COMPARE(seriesIndexSpy.size(), 2);
+    TRY_COMPARE(setIndexSpy1.size(), 1);
+    TRY_COMPARE(setIndexSpy2.size(), 1);
 
     //should leave set1, bar0
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -510,9 +484,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
 // hover in set1)
     QTest::mouseMove(view.viewport(), layout.at(2).center().toPoint());
 
-    TRY_COMPARE(seriesIndexSpy.count(), 2);
-    TRY_COMPARE(setIndexSpy1.count(), 1);
-    TRY_COMPARE(setIndexSpy2.count(), 1);
+    TRY_COMPARE(seriesIndexSpy.size(), 2);
+    TRY_COMPARE(setIndexSpy1.size(), 1);
+    TRY_COMPARE(setIndexSpy2.size(), 1);
 
     //should leave set2, bar0
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -547,9 +521,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
     QTest::mouseMove(view.viewport(), QPoint(layout.at(3).left(),
                                              (layout.at(3).top() + layout.at(4).bottom()) / 2));
 
-    TRY_COMPARE(seriesIndexSpy.count(), 1);
-    TRY_COMPARE(setIndexSpy1.count(), 1);
-    TRY_COMPARE(setIndexSpy2.count(), 0);
+    TRY_COMPARE(seriesIndexSpy.size(), 1);
+    TRY_COMPARE(setIndexSpy1.size(), 1);
+    TRY_COMPARE(setIndexSpy2.size(), 0);
 
     //should leave set1, bar1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -569,9 +543,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
 // move mouse on top of set2, bar1 to check the index (hover in set2)
     QTest::mouseMove(view.viewport(), layout.at(3).center().toPoint());
 
-    TRY_COMPARE(seriesIndexSpy.count(), 1);
-    TRY_COMPARE(setIndexSpy1.count(), 0);
-    TRY_COMPARE(setIndexSpy2.count(), 1);
+    TRY_COMPARE(seriesIndexSpy.size(), 1);
+    TRY_COMPARE(setIndexSpy1.size(), 0);
+    TRY_COMPARE(setIndexSpy2.size(), 1);
 
     //should enter set2, bar1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -593,9 +567,9 @@ void tst_QHorizontalPercentBarSeries::mousehovered()
                                              (layout.at(3).top() + layout.at(4).bottom()) / 2));
 
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
-    TRY_COMPARE(seriesIndexSpy.count(), 1);
-    TRY_COMPARE(setIndexSpy1.count(), 0);
-    TRY_COMPARE(setIndexSpy2.count(), 1);
+    TRY_COMPARE(seriesIndexSpy.size(), 1);
+    TRY_COMPARE(setIndexSpy1.size(), 0);
+    TRY_COMPARE(setIndexSpy2.size(), 1);
 
     //should leave set1, bar1
     seriesIndexSpyArg = seriesIndexSpy.takeFirst();
@@ -694,9 +668,9 @@ void tst_QHorizontalPercentBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -712,9 +686,9 @@ void tst_QHorizontalPercentBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -730,9 +704,9 @@ void tst_QHorizontalPercentBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(4).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -748,9 +722,9 @@ void tst_QHorizontalPercentBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -766,9 +740,9 @@ void tst_QHorizontalPercentBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(3).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -784,9 +758,9 @@ void tst_QHorizontalPercentBarSeries::mousePressed()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(5).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -859,9 +833,9 @@ void tst_QHorizontalPercentBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -877,9 +851,9 @@ void tst_QHorizontalPercentBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(2).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -895,9 +869,9 @@ void tst_QHorizontalPercentBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(4).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
@@ -913,9 +887,9 @@ void tst_QHorizontalPercentBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(1).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -931,9 +905,9 @@ void tst_QHorizontalPercentBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(3).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -949,9 +923,9 @@ void tst_QHorizontalPercentBarSeries::mouseReleased()
     QTest::mouseClick(view.viewport(), Qt::LeftButton, {}, layout.at(5).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 0);
-    QCOMPARE(setSpy2.count(), 1);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 0);
+    QCOMPARE(setSpy2.size(), 1);
 
     seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set2);
@@ -1023,9 +997,9 @@ void tst_QHorizontalPercentBarSeries::mouseDoubleClicked()
     QTest::mouseDClick(view.viewport(), Qt::LeftButton, {}, layout.at(0).center().toPoint());
     QCoreApplication::processEvents(QEventLoop::AllEvents, 1000);
 
-    QCOMPARE(seriesSpy.count(), 1);
-    QCOMPARE(setSpy1.count(), 1);
-    QCOMPARE(setSpy2.count(), 0);
+    QCOMPARE(seriesSpy.size(), 1);
+    QCOMPARE(setSpy1.size(), 1);
+    QCOMPARE(setSpy2.size(), 0);
 
     QList<QVariant> seriesSpyArg = seriesSpy.takeFirst();
     QCOMPARE(qvariant_cast<QBarSet*>(seriesSpyArg.at(1)), set1);
